@@ -52,6 +52,7 @@ my $feed_item_id1 = "INSERT_FEED_ITEM_ID1_HERE";
 my $feed_item_id2 = "INSERT_FEED_ITEM_ID2_HERE";
 my $feed_item_ids = [];
 
+# [START update_sitelink_campaign_extension_setting]
 sub update_sitelink_campaign_extension_setting {
   my ($api_client, $customer_id, $campaign_id, $feed_item_ids) = @_;
 
@@ -84,7 +85,7 @@ sub update_sitelink_campaign_extension_setting {
       updateMask => all_set_fields_of($campaign_extension_setting)});
 
   # Issue a mutate request to update the campaign extension setting.
-  my $campaign_extension_setting_response =
+  my $campaign_extension_settings_response =
     $api_client->CampaignExtensionSettingService()->mutate({
       customerId => $customer_id,
       operations => [$campaign_extension_setting_operation]});
@@ -92,10 +93,11 @@ sub update_sitelink_campaign_extension_setting {
   # Print the resource name of the updated campaign extension setting.
   printf
     "Updated a campaign extension setting with resource name: '%s'.\n",
-    $campaign_extension_setting_response->{results}[0]{resourceName};
+    $campaign_extension_settings_response->{results}[0]{resourceName};
 
   return 1;
 }
+# [END update_sitelink_campaign_extension_setting]
 
 # Don't run the example if the file is being included.
 if (abs_path($0) ne abs_path(__FILE__)) {
