@@ -97,13 +97,13 @@ sub create_campaign_budget {
     ->new({create => $campaign_budget});
 
   # Issue a mutate request to add the campaign budget.
-  my $campaign_budget_response =
+  my $campaign_budgets_response =
     $google_ads_client->CampaignBudgetService()->mutate({
       customerId => $customer_id,
       operations => [$campaign_budget_operation]});
 
   my $campaign_budget_resource_name =
-    $campaign_budget_response->{results}[0]{resourceName};
+    $campaign_budgets_response->{results}[0]{resourceName};
 
   my $created_campaign_budget =
     get_campaign_buget($google_ads_client, $customer_id,
@@ -167,12 +167,12 @@ sub create_campaign {
     new({create => $campaign});
 
   # Issue a mutate request to add the campaign.
-  my $campaign_response = $google_ads_client->CampaignService()->mutate({
+  my $campaigns_response = $google_ads_client->CampaignService()->mutate({
       customerId => $customer_id,
       operations => [$campaign_operation]});
 
   my $campaign_resource_name =
-    $campaign_response->{results}[0]{resourceName};
+    $campaigns_response->{results}[0]{resourceName};
 
   my $created_campaign =
     get_campaign($google_ads_client, $customer_id, $campaign_resource_name);
@@ -219,11 +219,11 @@ sub create_ad_group {
     new({create => $ad_group});
 
   # Issue a mutate request to add the ad group.
-  my $ad_group_response = $google_ads_client->AdGroupService()->mutate({
+  my $ad_groups_response = $google_ads_client->AdGroupService()->mutate({
       customerId => $customer_id,
       operations => [$ad_group_operation]});
 
-  my $ad_group_resource_name = $ad_group_response->{results}[0]{resourceName};
+  my $ad_group_resource_name = $ad_groups_response->{results}[0]{resourceName};
 
   my $created_ad_group =
     get_ad_group($google_ads_client, $customer_id, $ad_group_resource_name);
@@ -284,11 +284,11 @@ sub create_text_ads {
   }
 
   # Issue a mutate request to add the ad group ads.
-  my $ad_group_ad_response = $google_ads_client->AdGroupAdService()
+  my $ad_group_ads_response = $google_ads_client->AdGroupAdService()
     ->mutate({customerId => $customer_id, operations => $operations});
 
   my $new_ad_resource_names = [];
-  foreach my $result (@{$ad_group_ad_response->{results}}) {
+  foreach my $result (@{$ad_group_ads_response->{results}}) {
     push @$new_ad_resource_names, $result->{resourceName};
   }
 
@@ -359,12 +359,12 @@ sub create_keywords {
   }
 
   # Issue a mutate request to add the ad group criteria.
-  my $ad_group_criterion_response =
+  my $ad_group_criteria_response =
     $google_ads_client->AdGroupCriterionService()
     ->mutate({customerId => $customer_id, operations => $operations});
 
   my $new_ad_group_criterion_resource_names = [];
-  foreach my $result (@{$ad_group_criterion_response->{results}}) {
+  foreach my $result (@{$ad_group_criteria_response->{results}}) {
     push @$new_ad_group_criterion_resource_names, $result->{resourceName};
   }
 
