@@ -24,7 +24,7 @@ use File::HomeDir;
 use File::Spec::Functions;
 
 # Main version number that the rest of the modules pick up off of.
-our $VERSION = qv("6.0.1");
+our $VERSION = qv("6.1.0");
 
 use constant DEFAULT_PROPERTIES_FILE =>
   catfile(File::HomeDir->my_home, "googleads.properties");
@@ -33,6 +33,12 @@ use constant DEFAULT_PROPERTIES_FILE =>
 # specified version.
 use constant DEFAULT_API_VERSION => "V6";
 
+# The Google OAuth2 service base URL.
+use constant OAUTH2_BASE_URL => "https://accounts.google.com/o/oauth2";
+
+# The Google OAuth2 tokeninfo endpoint.
+use constant OAUTH2_TOKEN_INFO_URL => "https://oauth2.googleapis.com/tokeninfo";
+
 # Default OAuth2 scope for Google Ads API.
 use constant DEFAULT_OAUTH2_SCOPE => "https://www.googleapis.com/auth/adwords";
 
@@ -43,7 +49,7 @@ use constant NO_AUTH_HANDLER_SETUP_MESSAGE =>
   "https://github.com/googleads/google-ads-perl#getting-started";
 
 # Default Google Ads API service address.
-use constant DEFAULT_SERVICE_ADDRESS => "https://googleads.googleapis.com/";
+use constant DEFAULT_SERVICE_ADDRESS => "https://googleads.googleapis.com";
 
 # Default user-agent header for HTTP request.
 use constant DEFAULT_USER_AGENT => "gl-perl/" . substr($^V, 1);
@@ -83,6 +89,8 @@ use constant ENV_VAR_ENDPOINT           => "GOOGLE_ADS_ENDPOINT";
 use constant ENV_VAR_CLIENT_ID          => "GOOGLE_ADS_CLIENT_ID";
 use constant ENV_VAR_CLIENT_SECRET      => "GOOGLE_ADS_CLIENT_SECRET";
 use constant ENV_VAR_REFRESH_TOKEN      => "GOOGLE_ADS_REFRESH_TOKEN";
+use constant ENV_VAR_JSON_KEY_FILE_PATH => "GOOGLE_ADS_JSON_KEY_FILE_PATH";
+use constant ENV_VAR_IMPERSONATED_EMAIL => "GOOGLE_ADS_IMPERSONATED_EMAIL";
 use constant ENV_VAR_USER_AGENT         => "GOOGLE_ADS_PERL_USER_AGENT";
 use constant ENV_VAR_PROXY              => "GOOGLE_ADS_PERL_PROXY";
 
