@@ -22,7 +22,9 @@ use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 
 sub new {
   my ($class, $args) = @_;
-  my $self = {youtubeVideoId => $args->{youtubeVideoId}};
+  my $self = {
+    youtubeVideoId    => $args->{youtubeVideoId},
+    youtubeVideoTitle => $args->{youtubeVideoTitle}};
 
   # Delete the unassigned fields in this object for a more concise JSON payload
   remove_unassigned_fields($self, $args);
